"use client";

import useEmblaCarousel from "embla-carousel-react";
import Image from "next/image";
import { useCallback, useEffect, useState } from "react";

import { Button } from "@/components/ui/button";
import { ImageBaseUrl } from "@/configs/api";
import { Link } from "@/i18n/routing";
import { useLocale, useTranslations } from "next-intl";

export default function ServicesItems({ services }: { services: any[] }) {
	const locale = useLocale();
	const t = useTranslations();
	const [emblaRef, emblaApi] = useEmblaCarousel({
		align: "center",
		loop: services.length > 3,
		skipSnaps: false,
	});
	const [selectedIndex, setSelectedIndex] = useState(0);
	const [scrollSnaps, setScrollSnaps] = useState<number[]>([]);

	const scrollPrev = useCallback(() => emblaApi && emblaApi.scrollPrev(), [emblaApi]);
	const scrollNext = useCallback(() => emblaApi && emblaApi.scrollNext(), [emblaApi]);

	const onSelect = useCallback(() => {
		if (!emblaApi) return;
		setSelectedIndex(emblaApi.selectedScrollSnap());
	}, [emblaApi]);

	useEffect(() => {
		if (!emblaApi) return;
		onSelect();
		setScrollSnaps(emblaApi.scrollSnapList());
		emblaApi.on("select", onSelect);
		emblaApi.on("reInit", onSelect);
	}, [emblaApi, onSelect]);

	const showNavigation = services.length > 3;

	return (
		<div className="w-full rounded-lg">
			<div className="relative mx-auto max-w-7xl">
				<div className="overflow-hidden" ref={emblaRef}>
					<div className="flex justify-center">
						{services?.filter((service: any) => service?.show_in_site === 1)?.map((service: any) => (
							<div
								key={service.id}
								style={{ boxShadow: "16px 16px 32px 0px #00000040" }}
								className="flex-[0_0_100%] min-w-0 px-2 sm:flex-[0_0_50%] lg:flex-[0_0_33.333%]"
							>
								<div className="group relative overflow-hidden rounded-lg">
									<div>
										<Image
											src={ImageBaseUrl + service?.thumbnail?.image_path}
											alt={service?.thumbnail?.name}
											width={392}
											height={350}
											className="h-full w-full rounded-lg object-cover"
											style={{ height: "486px" }}
										/>
									</div>
									<div className="absolute bottom-0 left-0 right-0 flex min-h-[40%] translate-y-0 transform flex-col items-center justify-center bg-[#5C5C5C9C] p-[21px] transition-transform duration-300">
										<h3 className="mb-4 text-2xl text-custom-background-light">
											{locale === "ar" ? service?.name_ar : service?.name_en}
										</h3>
										<p className="mb-4 text-center text-[15px] leading-7 text-custom-background-light">
											{locale === "ar" ? service?.description_ar : service?.description_en}
										</p>
										<Button
											variant="secondary"
											className="rounded-md bg-[#2895C8] text-white hover:bg-custom-secondary/90" //service_slug
										>
											<Link href={`/services/${service?.id}` as any}>{t("Details")}</Link>
										</Button>
									</div>
								</div>
							</div>
						))}
					</div>
				</div>
				{showNavigation && (
					<>
						<button
							className="absolute left-4 top-1/2 -translate-y-1/2 rounded-full bg-white/80 p-2 text-gray-800 hover:bg-white"
							onClick={scrollPrev}
						>
							<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5} stroke="currentColor" className="w-6 h-6">
								<path strokeLinecap="round" strokeLinejoin="round" d="M15.75 19.5L8.25 12l7.5-7.5" />
							</svg>
						</button>
						<button
							className="absolute right-4 top-1/2 -translate-y-1/2 rounded-full bg-white/80 p-2 text-gray-800 hover:bg-white"
							onClick={scrollNext}
						>
							<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5} stroke="currentColor" className="w-6 h-6">
								<path strokeLinecap="round" strokeLinejoin="round" d="M8.25 4.5l7.5 7.5-7.5 7.5" />
							</svg>
						</button>
					</>
				)}
			</div>
			{showNavigation && (
				<div className="mt-4 flex justify-center gap-2">
					{scrollSnaps.map((_, index) => (
						<button
							key={index}
							className={`h-2 w-2 rounded-full ${index === selectedIndex ? "bg-[#2895C8]" : "bg-gray-300"}`}
							onClick={() => emblaApi?.scrollTo(index)}
						/>
					))}
				</div>
			)}
		</div>
	);
}
